==> haskell-rope-utf16-splay-0.4.0.0-85-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rope-utf16-splay.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rope-utf16-splay
version:              0.4.0.0
visibility:           public
id:                   rope-utf16-splay-0.4.0.0-4koXrjXMcVCLOyRO1mH42N
key:                  rope-utf16-splay-0.4.0.0-4koXrjXMcVCLOyRO1mH42N
license:              BSD-3-Clause
copyright:            (c) 2018-2022 Olle Fredriksson
maintainer:           fredriksson.olle@gmail.com
author:               Olle Fredriksson
homepage:             https://github.com/ollef/rope-utf16-splay
synopsis:
    Ropes optimised for updating using UTF-16 code units and
    row/column pairs.

description:
    Ropes optimised for updating using UTF-16 code units and
    row/column pairs.  This implementation uses splay trees
    instead of the usual finger trees. According to my
    benchmarks, splay trees are faster in most situations.

category:             Data, Text, Language
abi:                  f56bef35c7e5dfc722682d2ed9a3eed7
exposed:              True
exposed-modules:
    Data.Rope.UTF16 Data.Rope.UTF16.Internal
    Data.Rope.UTF16.Internal.Position Data.Rope.UTF16.Internal.Text
    Data.SplayTree

import-dirs:          /usr/lib/ghc-9.6.6/site-local/rope-utf16-splay-0.4.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rope-utf16-splay-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rope-utf16-splay-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rope-utf16-splay
hs-libraries:         HSrope-utf16-splay-0.4.0.0-4koXrjXMcVCLOyRO1mH42N
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-rope-utf16-splay/html/rope-utf16-splay.haddock

haddock-html:         /usr/share/doc/haskell-rope-utf16-splay/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rope-utf16-splay-0.4.0.0-86-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-rope-utf16-splay.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rope-utf16-splay
version:              0.4.0.0
visibility:           public
id:                   rope-utf16-splay-0.4.0.0-JXIAYAGCZaaJjC7I3N8jEY
key:                  rope-utf16-splay-0.4.0.0-JXIAYAGCZaaJjC7I3N8jEY
license:              BSD-3-Clause
copyright:            (c) 2018-2022 Olle Fredriksson
maintainer:           fredriksson.olle@gmail.com
author:               Olle Fredriksson
homepage:             https://github.com/ollef/rope-utf16-splay
synopsis:
    Ropes optimised for updating using UTF-16 code units and
    row/column pairs.

description:
    Ropes optimised for updating using UTF-16 code units and
    row/column pairs.  This implementation uses splay trees
    instead of the usual finger trees. According to my
    benchmarks, splay trees are faster in most situations.

category:             Data, Text, Language
abi:                  c57730bcab02355204ae705bdcc62b37
exposed:              True
exposed-modules:
    Data.Rope.UTF16 Data.Rope.UTF16.Internal
    Data.Rope.UTF16.Internal.Position Data.Rope.UTF16.Internal.Text
    Data.SplayTree

import-dirs:          /usr/lib/ghc-9.6.6/site-local/rope-utf16-splay-0.4.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/rope-utf16-splay-0.4.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/rope-utf16-splay-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rope-utf16-splay
hs-libraries:         HSrope-utf16-splay-0.4.0.0-JXIAYAGCZaaJjC7I3N8jEY
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-rope-utf16-splay/html/rope-utf16-splay.haddock

haddock-html:         /usr/share/doc/haskell-rope-utf16-splay/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
